@@ -3,6 +3,7 @@ from __future__ import absolute_import
 from jpmml_evaluator import _classpath, JavaBackend
 from py4j.java_gateway import JavaGateway
 
+import numpy
 import os
 
 def launch_gateway(user_classpath = []):
@@ -21,11 +22,17 @@ class Py4JBackend(JavaBackend):
 	def dict2map(self, pyDict):
 		javaMap = self.newObject("java.util.LinkedHashMap")
 		for k, v in pyDict.items():
+			if isinstance(v, numpy.int8) or isinstance(v, numpy.int16) or isinstance(v, numpy.int32):
+				v = self.newObject("java.lang.Integer", int(v))
+			elif isinstance(v, numpy.float32):
+				v = self.newObject("java.lang.Float", float(v))
+			elif isinstance(v, numpy.float64):
+				v = self.newObject("java.lang.Double", float(v))
 			javaMap.put(k, v)
 		return javaMap
 
 	def map2dict(self, javaMap):
-		return javaMap
+		return dict(javaMap)
 
 	def staticInvoke(self, className, methodName, *args):
 		javaClass = self.gateway.jvm.__getattr__(className)
